use crate::configuration::compose_types::DockerCompose;
use crate::helpers::dir::parent_dir_name;
use bollard::volume::CreateVolumeOptions;
use bollard::Docker;

pub(crate) async fn create_volumes(compose: &DockerCompose, docker: &Docker) -> anyhow::Result<()> {
    if let Some(volumes) = &compose.volumes {
        let parent_dir = parent_dir_name()?;
        for (name, volume) in volumes {
            docker
                .create_volume::<String>(CreateVolumeOptions {
                    name: format!("{}_{}", parent_dir, name),
                    driver: volume.driver.clone().unwrap_or_else(Default::default),
                    driver_opts: volume.driver_opts.clone().unwrap_or_else(Default::default),
                    labels: volume.labels.clone().unwrap_or_else(Default::default),
                })
                .await?;
        }
    }
    Ok(())
}
